﻿using Infragistics.Controls.Schedules;
using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.ComponentModel;
using System.Linq;
using System.Runtime.CompilerServices;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Media;

namespace XamGanttListBackedProjectCase
{
    public class ViewModel : ObservableModel
    {
        public ObservableCollection<TaskModel> TaskData { get; set; }

        private GanttGridRow? _row;
        public GanttGridRow? ActivatedRow
        {
            get { return _row; }
            set
            {
                if(!(_row.Equals(value)))
                {
                    _row = value;
                    OnPropertyChanged();
                }
            }
        }

        public ViewModel()
        {
            TaskData = new ObservableCollection<TaskModel>();

            TaskModel parentTask = new TaskModel() { Name = "Parent Task 1", StartTime = DateTime.Now, Length = new TimeSpan(1, 0, 0, 0), TaskID = 0 };

            TaskModel childTask1 = new TaskModel() { Name = "Child Task 1", StartTime = DateTime.Now, Length = new TimeSpan(3, 0, 0), TaskID = 1, TaskBrush = new SolidColorBrush(Colors.Red) };
            TaskModel childTask2 = new TaskModel() { Name = "Child Task 2", StartTime = DateTime.Now.AddHours(3), Length = new TimeSpan(8, 0, 0), TaskID = 2, TaskBrush = new SolidColorBrush(Colors.Yellow) };
            TaskModel childTask3 = new TaskModel() { Name = "Child Task 3", StartTime = DateTime.Now.AddHours(6), Length = new TimeSpan(16, 0, 0), TaskID = 3, TaskBrush = new SolidColorBrush(Colors.Blue)};           

            TaskData.Add(childTask1);
            TaskData.Add(childTask2);
            TaskData.Add(childTask3);

            TaskModel parentTask2 = new TaskModel() { Name = "Parent Task 2", StartTime = DateTime.Now, Length = new TimeSpan(1, 0, 0, 0), IsManualTask = true, TaskID = 4 };

            TaskModel childTask4 = new TaskModel() { Name = "Manual Child 1", StartTime = DateTime.Now, Length = new TimeSpan(5, 0, 0), IsManualTask = true, TaskID = 5, TaskBrush = new SolidColorBrush(Colors.Orange) };
            TaskModel childTask5 = new TaskModel() { Name = "Manual Child 2", StartTime = DateTime.Now.AddHours(5), Length = new TimeSpan(5, 0, 0), IsManualTask = true, TaskID = 6, TaskBrush = new SolidColorBrush(Colors.Green) };

            TaskData.Add(parentTask2);
            TaskData.Add(childTask4);
            TaskData.Add(childTask5);

            parentTask.ChildTasks = "1, 2, 3";

            parentTask2.ChildTasks = "5, 6";

            parentTask2.TaskResources = "IG Support Team";

            childTask2.Preds = "1";

            TaskData.Add(parentTask);
        }
    }

    public class TaskModel : ObservableModel
    {
        public string ChildTasks { get; set; } //Tasks collection -> CSV's.
        public string Name { get; set; } //TaskName
        public DateTime StartTime { get; set; } //Start   
        public DateTime EndTime { get; set; } //Finish
             
        public bool IsManualTask { get; set; } //IsManual
        public TimeSpan Length { get; set; } //Duration   
        public int TaskID { get; set; } //DataItemID        
        public DateTime? ConstraintDate { get; set; } //Default.
        public ProjectTaskConstraintType ConstraintType { get; set; } //Default.
        public string TaskResources { get; set; }


        private string _pred;
        public string Preds //Predecessors
        {
            get { return _pred; }
            set
            {
                if(_pred != value)
                {
                    _pred = value;
                    OnPropertyChanged();
                }
            }
        }
        public ProjectDurationFormat Format { get; set; } //DurationFormat      

        public SolidColorBrush TaskBrush { get; set; }

    }

    public class ObservableModel : INotifyPropertyChanged
    {
        public event PropertyChangedEventHandler PropertyChanged;
        public void OnPropertyChanged([CallerMemberName] String propertyName = "")
        {
            if (PropertyChanged != null)
            {
                PropertyChanged(this, new PropertyChangedEventArgs(propertyName));
            }
        }

    }
}
